@@ -7,13 +7,14 @@ use strict;
 
 package XML::Compile::SOAP::Daemon::PSGI;
 use vars '$VERSION';
-$VERSION = '3.04';
+$VERSION = '3.05';
 
 use base 'XML::Compile::SOAP::Daemon', 'Plack::Component';
 
 use Log::Report 'xml-compile-soap-daemon';
 use Encode;
 use Plack::Request;
+use Plack::Response;
 
 
 use constant
@@ -53,7 +54,12 @@ sub _init($)
 sub call($)
 {   my ($self, $env) = @_;
     my $res = eval { $self->_call($env) };
-    $@ ? [ RC_SERVER_ERROR, [Content_Type => 'text/plain'], [$@] ] : $res;
+    $res ||= Plack::Response->new
+      ( RC_SERVER_ERROR
+      , [Content_Type => 'text/plain']
+      , [$@]
+      );
+    $res->finalize;
 }
 
 sub _call($;$)
@@ -116,7 +122,7 @@ sub _call($;$)
     }
 
     $res->content_length(length $bytes);
-    $res->finalize;
+    $res;
 }
 
 sub setWsdlResponse($)
@@ -138,7 +144,7 @@ sub sendWsdl($)
       , Content_Length => length($self->{wsdl_data})
       }, $self->{wsdl_data});
 
-    $res->finalize;
+    $res;
 }
 
 #-----------------------------
